#
# spec file for package python-Fiona
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Fiona
Version:        1.10.1
Release:        1.1
Summary:        Module for reading and writing spatial data files
License:        BSD-3-Clause
URL:            https://github.com/Toblerity/Fiona
Source:         https://files.pythonhosted.org/packages/source/f/fiona/fiona-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gdal
BuildRequires:  libgdal-devel
BuildRequires:  proj
BuildRequires:  proj-devel
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.2
Requires:       python-certifi
Requires:       python-click >= 8.0
Requires:       python-click-plugins
Requires:       python-cligj >= 0.5
Recommends:     python-Shapely
Recommends:     python-boto3
Recommends:     python-pyparsing
# SECTION test requirements
BuildRequires:  %{python_module Shapely}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module attrs >= 19.2}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module click >= 8.0}
BuildRequires:  %{python_module click-plugins}
BuildRequires:  %{python_module cligj >= 0.5}
BuildRequires:  %{python_module fsspec}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pyproj}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
# /SECTION
Recommends:     fiona-fio
%python_subpackages

%description
Fiona is OGR's spatial data API for Python programmers.

%package     -n fiona-fio
Summary:        Program for reading and writing spatial data files
Group:          Productivity/Scientific/Other
Requires:       python3-Fiona = %{version}
Conflicts:      fio
BuildArch:      noarch

%description -n fiona-fio
Command-line interface for reading and writing spatial data
using OGR's Fiona package.

%prep
%autosetup -p1 -n fiona-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# The following require network
skiptests="wheel or test_open_zip_https or test_open_http or test_collection_http or test_collection_zip_http or test_opener_fsspec_zip_http_fs"
# Reason for this failure not recorded
skiptests="$skiptests or GPSTrackMaker"
# December 2022: test_no_append_driver_cannot_append has started failing for FlatGeobuf and GeoJSONSeq only
skiptests="$skiptests or (test_no_append_driver_cannot_append and (FlatGeobuf or GeoJSONSeq))"

mv fiona fiona_temp
export GDAL_DATA=$(pkg-config --variable=datadir gdal)
export PROJ_LIB=$(pkg-config --variable=datadir proj)
export LANG=en_US.UTF-8
%pytest_arch -rs -k "not ($skiptests)"
mv fiona_temp fiona

%files %{python_files}
%doc CHANGES.txt CREDITS.txt README.rst
%license LICENSE.txt
%{python_sitearch}/fiona
%{python_sitearch}/fiona-%{version}.dist-info

%files -n fiona-fio
%license LICENSE.txt
%{_bindir}/fio

%changelog
* Thu Apr 10 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.10.1:
  * Bug fixes:
    + Logging in the CRS class no longer tries to print representations of
    objects that may be NULL when searching for authority matches.
    + The truncate VSI plugin callback has been implemented.
    + The Pyopener registry and VSI plugin have been rewritten to avoid
    filename conflicts and to be compatible with multithreading.
    + A CSLConstList ctypedef has been added and is used where appropriate.
    + Fiona model objects have a informative, printable representation again.
    + Fiona can again set fields with values that are instances of classes
    derived from date, time, and datetime.
    + Fiona's python opener VSI plugin prefix has been changed to
    "vsifiopener"
    + Add a 16-bit integer type "int16" based on OGR's OSFTInt16 integer
    sub-type.
    + Allow a GeoJSON collection's layer name to be set on opening in
    write mode
    + An implementation of the VSI flush callback has been added to
    _vsiopener.pyx.
    + Openers are now registered only by urlpath. The mode is no longer
    considered as OGR drivers may use a mix of modes when creating a
    new dataset.
  * New features:
  + All supported Fiona field types are now represented by classes in
    fiona.schema.
  + The filter, map, and reduce CLI commands from the public domain
    version 1.1.0 of fio-planet have been incorporated into Fiona's core
    set of commands
  + Python openers can now support discovery of auxiliary "sidecar" files
    like .aux.xml, .msk, and .tfw files for GeoTIFFs.
- Drop patch 1314.patch, now included upstream.
* Wed Jun 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.9.6
  * Ensure that geometry types in a schema are translated to a linear type,
    as geometry instances are (#1313).
  * Fix broken stable API documentation on Read The Docs (#).
  * Remove install requirement of setuptools, a regression introduced in 1.9.5.
- from 1.9.5
  * Expand keys in schema mismatch exception, resolving #1278.
  * Preserve the null properties and geometry of a Feature when serializing (#1276).
  * The distribution name is now officially "fiona", not "Fiona". The import name
    remains "fiona".
  * Builds now require Cython >= 3.0.2 (#1276).
  * PyPI wheels include GDAL 3.6.4, PROJ 9.0.1, and GEOS 3.11.2.
  * PyPI wheels include curl 8.4.0, addressing CVE-2023-38545 and CVE-38546.
  * PyPI wheels are now available for Python 3.12.
- from 1.9.4.post1
  * Extraneous files were unintentionally packaged in the 1.9.4 wheels. This
    post1 release excludes them so that wheel contents are as in version 1.9.3.
- from 1.9.4
  * The performance of Feature.from_dict() has been improved (#1267).
  * Several sources of meaningless log messages from fiona._geometry about NULL
    geometries are avoided (#1264).
  * The Parquet driver has been added to the list of supported drivers and will
    be available if your system's GDAL library links libarrow. Note that fiona
    wheels on PyPI do not include libarrow as it is rather large.
  * Ensure that fiona._vendor modules are found and included.
  * Bytes type feature properties are now hex encoded when serializing to GeoJSON (#1263).
  * Docstrings for listdir and listlayers have been clarified and harmonized.
  * Nose style test cases have been converted to unittest.TestCase (#1256).
  * The munch package used by fio-filter and fio-calc is now vendored and patched
    to remove usage of the deprecated pkg_resources module (#1255).
- from 1.9.3
  * Rasterio CRS objects are compatible with the Collection constructor and are
    now accepted (#1248).
  * Enable append mode for fio-load (#1237).
  * Reading a GeoJSON with an empty array property can result in a segmentation
    fault since version 1.9.0. This has been fixed (#1228).
- from 1.9.2
  * Get command entry points using importlib.metadata (#1220).
  * Instead of warning, transform_geom() raises an exception when some points
    can't be reprojected unless the caller opts in to partial reprojection. This
    restores the behavior of version 1.8.22.
  * Add support for open options to all CLI commands that call fiona.open (#1215).
  * Fix a memory leak that can occur when iterating over a dataset using strides (#1205).
  * ZipMemoryFile now supports zipped GDB data (#1203).
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Drop support for older Python versions
- Update name for dist directory in %%files section
- Cherry-pick upstream patch to fix build with GCC 14
  * https://github.com/Toblerity/Fiona/pull/1314.patch
* Sun Feb 26 2023 Matej Cepl <mcepl@suse.com>
- Update to 1.9.1:
  The 1.9.0 release revealed a few bugs. Here are the ones we
  felt should be squished immediately.
  - Log a warning message when identically named fields are
    encountered (#1201).
  - Avoid dependence on listdir order in tests (#1193).
  - Prevent empty geometries arrays from appearing in
    __geo_interface__ (#1197).
  - setuptools added to pyproject.toml. Its pkg_resources module
    is used by the CLI (#1191).
- Update to 1.9.0:
  - Deprecations
  - The precision keyword argument of
    fiona.transform.transform_geom is deprecated and will be
    removed in version 2.0.
  - The fiona.drivers() function has been deprecated and
    will be removed in version 2.0. It should be replaced by
    fiona.Env().
  - The new fiona.meta module will be renamed to fiona.drivers
    in version 2.0.
  - The major new features are:
  - A new CRS class identical to Rasterio's.
  - New Feature and Geometry classes. These are returned
    instead of dicts but are compatible with version 1.8's
    dicts.
  - Access to format driver metadata.
  Please see the change log entries for 1.9 pre-releases at
  https://github.com/Toblerity/Fiona/releases to see a complete
  list of new features and bug fixes.
* Thu Dec  1 2022 John Vandenberg <jayvdb@gmail.com>
- Skip two failing tests
* Thu Sep 15 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.8.21
  * Driver mode support tests have been made more general and less
    susceptible to driver quirks involving feature fields and
    coordinate values.
  * OSError is raised on attempts to open a dataset in a Python
    file object in "a" mode.
  * Upgrade attrs, cython, etc to open up Python 3.10 support
  * Allow FieldSkipLogFilter to handle exception messages as well as strings
  * Clean up VSI files left by MemoryFileBase
  * Hard-coded "utf-8" collection encoding has been removed
- from v1.8.20
  * Allow use with click 8 and higher
- from v1.8.19
  * In fiona/env.py the GDAL data path is now configured using
    set_gdal_config instead by setting the GDAL_DATA environment variable
  * Spurious iterator reset warnings have been eliminated.
- from v1.8.18
  * The precision option of transform has been fixed for the case of
    GeometryCollections
  * Added missing --co (creation) option to fio-load
  * If the certifi package can be imported, its certificate store
    location will be passed to GDAL during import of fiona._env unless
    CURL_CA_BUNDLE is already set.
  * Warn when feature fields named "" are found
- from v1.8.17
  * To fix issue #952 the fio-cat command no longer cuts feature
    geometries at the anti-meridian by default. A --cut-at-antimeridian
    option has been added to allow cutting of geometries in a geographic
    destination coordinate reference system.
- from v1.8.16
  * More OGR errors and warnings arising in calls to GDAL C API functions
    are surfaced.
  * A circular import introduced in some cases in 1.8.15 has been fixed
- from v1.8.15
  * Change shim functions to not return tuples
  * Raise a Python exception when VSIFOpenL fails.
- from v1.8.14
  * When creating a new Collection in a MemoryFile with a default (random) name
    Fiona will attempt to use a format driver-supported file extension.
    When initializing a MemoryFile with bytes of data formatted for a vector
    driver that requires a certain file name or extension, the user should
    continue to pass an appropriate filename and/or extension.
  * Read support for FlatGeobuf has been enabled in the drvsupport module.
  * The MemoryFile implementation has been improved so that it can support multi-part
    S3 downloads (#906). This is largely a port of code from rasterio.
  * Axis ordering for results of fiona.transform was wrong when CRS were
    passed in the "EPSG:dddd" form.
  * Allow implicit access to the only dataset in a ZipMemoryFile.
    The path argument of ZipMemoryFile.open() is now optional
  * Improve support for datetime types: support milliseconds, timezones
    and improve warnings if type is not supported by driver
  * Fix "Failed to commit transaction" TransactionError for FileGDB driver.
  * Load GDAL DLL dependencies on Python 3.8+ / Windows with add_dll_directory()
  * Do not require optional properties
  * Ensure that slice does not overflow available data
  * Resolve issue when "ERROR 4: Unable to open EPSG support file gcs.csv."
    is raised on importing fiona.
  * Resolve issue resulting in possible mixed up fields names (affecting
    only DXF, GPX, GPSTrackMacker and DGN driver)
  * Ensure crs_wkt is passed when writing to MemoryFile
* Sat Mar 14 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 1.18.13.post1
  + improve binary wheel compatibility with shapely 1.7.0
  + All update are referenced online or in the package
    https://github.com/Toblerity/Fiona/blob/master/CHANGES.txt
- Fix tests error with proj.db (datadir instead libdir)
- Make only python3 as we don't have anymore python2-pyproj
- spec-cleaner
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Fix dependencies.
- Enable unit tests
- Ran spec-cleaner
* Mon Apr  1 2019 Todd R <toddrme2178@gmail.com>
- Split executable into own module to avoid conflicts with fio.
  fio is a Linux Kernel project so we probably don't want to make
  fiona conflict with it completely.
* Fri Mar 29 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description. Use noun phrase in summary.
* Thu Mar 28 2019 Todd R <toddrme2178@gmail.com>
- Update to last version 1.8.6
  * The advertisement for JSON driver enablement in 1.8.5 was false (#176), but
    in this release they are ready for use.
- Update to last version 1.8.5
  * GDAL seems to work best if GDAL_DATA is set as early as possible. Ideally it
    is set when building the library or in the environment before importing
    Fiona, but for wheels we patch GDAL_DATA into os.environ when fiona.env
    is imported. This resolves #731.
  * A combination of bugs which allowed .cpg files to be overlooked has been
    fixed (#726).
  * On entering a collection context (Collection.__enter__) a new anonymous GDAL
    environment is created if needed and entered. This makes `with
    fiona.open(...) as collection:` roughly equivalent to `with fiona.open(...)
    as collection, Env():`. This helps prevent bugs when Collections are created
    and then used later or in different scopes.
  * Missing GDAL support for TopoJSON, GeoJSONSeq, and ESRIJSON has been enabled
    (#721).
  * A regression in handling of polygons with M values (#724) has been fixed.
  * Per-feature debug logging calls in OGRFeatureBuilder methods have been
    eliminated to improve feature writing performance (#718).
  * Native support for datasets in Google Cloud Storage identified by "gs"
    resource names has been added (#709).
  * Support has been added for triangle, polyhedral surface, and TIN geometry
    types (#679).
  * Notes about using the MemoryFile and ZipMemoryFile classes has been added to
    the manual (#674).
* Wed Mar  6 2019 Martin Pluskal <mpluskal@suse.com>
- Rename package to python-Fiona
- Install license and documentation
* Wed Mar  6 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to last version 1.8.4
  + There are no known breaking changes in 1.8.0. Python warnings
    should be expected in several cases of class and method
    deprecation.
  + The fiona.drivers() context manager is being replaced by
    fiona.Env(), which also registers format drivers and has the
    same properties as the GDAL configuration manager in Rasterio.
  + Collection slicing will be disallowed in a future version of
    Fiona to remove the confusion between mapping and list semantics
    for Collection objects. Code such as
    fiona.open(“example.shp”)[1:10]
    should be changed to list(fiona.open(“example.shp”))[1:10].
- Packaging: Minimal spec-cleaner
  + Remove unneeded requires: python
* Sun Oct 21 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to last version 1.7.13
  Including fix for boo#1107387
- Packaging:
  + redone spec with py2pac singlespec
  + package is not noarch
  + /usr/bin/fio is distributed only for python3
* Tue Jun  9 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- initial packaging (1.5.1)
